@@ -129,7 +129,7 @@ static xmlNodePtr create_toc_tree(char *docpath, char outputprefs)
     xmlDefaultSAXHandler.fatalError = xml_fatal_error_handler;
     if (toc_doc == NULL)
     {
-        sk_message(outputprefs, SKOUT_DEFAULT, SKOUT_QUIET, "(install)", _("TOC file does does not exist, is not readable, or is not well-formed XML: %s\n"), tocpath);
+        sk_message(outputprefs, SKOUT_DEFAULT, SKOUT_QUIET, "(install)", _("TOC file does not exist, is not readable, or is not well-formed XML: %s\n"), tocpath);
         return NULL;
     }
     toc_tree = toc_doc->children;
@@ -144,11 +144,17 @@ static xmlNodePtr create_toc_tree(char *docpath, char outputprefs)
     return toc_tree;
 }
 
+
+/* 
+ * FIXME: This function should be rewritten to provide warnings/errors for all
+ * cases in which it doesn't install an OMF entry. Currently it may fail
+ *  silently for a variety of reasons. 
+ */
 int install(char *omf_name, char *scrollkeeper_dir, char *data_dir, char outputprefs)
 {    
     xmlDocPtr omf_doc;
     xmlDtdPtr dtd;
-    xmlNodePtr node, s_node;
+    xmlNodePtr node, omf_node, s_node;
     char *docpath, *title, *format, str[1024];
     char cl_filename[PATHLEN], cl_ext_filename[PATHLEN];
     char locale_dir[PATHLEN], locale_name[PATHLEN], *locale, *ptr;
@@ -164,7 +170,7 @@ int install(char *omf_name, char *scrollkeeper_dir, char *data_dir, char outputp
     omf_doc = xmlParseFile(omf_name);
     if (omf_doc == NULL)
     {
-        sk_message(outputprefs, SKOUT_DEFAULT, SKOUT_QUIET, "(install)", _("OMF file does does not exist, is not readable, or is not well-formed XML: %s\n"), omf_name);
+        sk_message(outputprefs, SKOUT_DEFAULT, SKOUT_QUIET, "(install)", _("OMF file does not exist, is not readable, or is not well-formed XML: %s\n"), omf_name);
         return 0;
     }
 
@@ -189,11 +195,25 @@ int install(char *omf_name, char *scrollkeeper_dir, char *data_dir, char outputp
 		      	          
     snprintf(scrollkeeper_docs, PATHLEN, "%s/scrollkeeper_docs", scrollkeeper_dir);
     
-    /* we assume that this file is a concatenation of "resource" tags so
-       they should start from the top node's children
-    */
+    /* We assume that this file is a concatenation of "resource" tags so
+     * they should start from the top node's children.
+     */
 
-    for(node = omf_doc->children->children; node != NULL; node = node->next)
+    /* Well, sort of. Let's do the right thing when comments are involved. */
+    for(omf_node = omf_doc->children; (omf_node != NULL) && (omf_node->type != XML_ELEMENT_NODE); omf_node = omf_node->next) ;;
+
+    if (!omf_node) {
+        /* This should not happen */
+        sk_message(outputprefs, SKOUT_DEFAULT, SKOUT_QUIET, "(install)", _("Failed to locate an <OMF> element.\n"));
+        return 0;
+    }
+    if (!omf_node->children) {
+        /* This should not happen */
+        sk_message(outputprefs, SKOUT_DEFAULT, SKOUT_QUIET, "(install)", _("<OMF> node has no children.\n"));
+        return 0;
+    }
+
+    for(node = omf_node->children; node != NULL; node = node->next)
     {
         if (!xmlStrcmp(node->name, (xmlChar *)"resource"))
 	{
